@@ -15,7 +15,7 @@ from pymoo.model.repair import Repair
 import numpy as np
 from dovado_rtl.simple_types import Metric
 from dovado_rtl.fitness import FitnessEvaluator
-import pickle
+import dill as pickle
 
 
 class MyRepair(Repair):
